@@ -1,7 +1,7 @@
 (* 
  * prooftree --- proof tree display for Proof General
  * 
- * Copyright (C) 2011, 2012 Hendrik Tews
+ * Copyright (C) 2011 - 2013 Hendrik Tews
  * 
  * This file is part of "prooftree".
  * 
@@ -19,7 +19,7 @@
  * You should have received a copy of the GNU General Public License
  * along with "prooftree". If not, see <http://www.gnu.org/licenses/>.
  * 
- * $Id: draw_tree.ml,v 1.46 2013/01/20 21:55:54 tews Exp $
+ * $Id: draw_tree.ml,v 1.48 2013/03/28 08:02:00 tews Exp $
  *)
 
 
@@ -757,7 +757,11 @@ object (self)
     match parent with 
       | None -> 
 	(match tree_layer with
-	  | None -> assert false
+	  | None -> 
+	    (* during bottom-up clone copy there is no parent and the
+	     * tree_layer will be installed later
+	     *)
+	    ()
 	  | Some sco -> sco#clear_size_cache
 	)
       | Some p -> p#update_sizes_in_branch
