@@ -1,7 +1,7 @@
 (* 
  * prooftree --- proof tree display for Proof General
  * 
- * Copyright (C) 2011, 2012 Hendrik Tews
+ * Copyright (C) 2011 - 2013 Hendrik Tews
  * 
  * This file is part of "prooftree".
  * 
@@ -19,12 +19,12 @@
  * You should have received a copy of the GNU General Public License
  * along with "prooftree". If not, see <http://www.gnu.org/licenses/>.
  * 
- * $Id: ext_dialog.ml,v 1.13 2013/01/18 16:39:10 tews Exp $
+ * $Id: ext_dialog.ml,v 1.15 2013/03/28 08:02:00 tews Exp $
  *)
 
 (** The Existential Variable Dialog *)
 
-open Util
+(* open Util *)
 open Gtk_ext
 open Configuration
 open Draw_tree
